@@ -26,17 +26,17 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare '
-           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-           '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-           '-fexceptions   -O3',
+           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+           '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+           '-fcf-protection   -O3',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/multibytecodec.h '
-                          '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/cjkcodecs.h',
+ 'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
+                          '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-fcf-protection -fexceptions',
+ 'CONFIGURE_CFLAGS': '-fexceptions -fcf-protection',
  'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Wno-complain-wrong-lang -Werror=format-security '
@@ -92,24 +92,24 @@ build_time_vars = {'ABIFLAGS': '',
                 "'build_alias=x86_64-redhat-linux-gnu' "
                 "'host_alias=x86_64-redhat-linux-gnu' "
                 "'PKG_CONFIG_PATH=:/usr/lib64/pkgconfig:/usr/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-fcf-protection -fexceptions  ' 'LDFLAGS= ' "
+                "'CC=gcc' 'CFLAGS=-fexceptions -fcf-protection  ' 'LDFLAGS= ' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.12.5/build/optimized/coverage.info',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.12.6/build/optimized/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.12.5/build/optimized/lcov-report',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.12.6/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.12.5/Include',
+             '-I/builddir/build/BUILD/Python-3.12.6/Include',
  'CXX': 'g++',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
- 'DEEPFREEZE_DEPS': '/builddir/build/BUILD/Python-3.12.5/Tools/build/deepfreeze.py '
+ 'DEEPFREEZE_DEPS': '/builddir/build/BUILD/Python-3.12.6/Tools/build/deepfreeze.py '
                     '_bootstrap_python '
-                    '/builddir/build/BUILD/Python-3.12.5/Programs/_freeze_module.py '
+                    '/builddir/build/BUILD/Python-3.12.6/Programs/_freeze_module.py '
                     '\\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.12 '
@@ -148,11 +148,11 @@ build_time_vars = {'ABIFLAGS': '',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FREEZE_MODULE': './_bootstrap_python '
-                  '/builddir/build/BUILD/Python-3.12.5/Programs/_freeze_module.py',
+                  '/builddir/build/BUILD/Python-3.12.6/Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
  'FREEZE_MODULE_DEPS': '_bootstrap_python '
-                       '/builddir/build/BUILD/Python-3.12.5/Programs/_freeze_module.py',
+                       '/builddir/build/BUILD/Python-3.12.6/Programs/_freeze_module.py',
  'FROZEN_FILES_IN': '\\',
  'FROZEN_FILES_OUT': '\\',
  'GETPGRP_HAVE_ARG': 0,
@@ -673,9 +673,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-                    '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                    '-fexceptions   -O3 -flto=auto -ffat-lto-objects '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                    '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                    '-fcf-protection   -O3 -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                     '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -703,16 +703,16 @@ build_time_vars = {'ABIFLAGS': '',
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
                     '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                     '-fwrapv -O3 -fprofile-use -fprofile-correction '
-                    '-I/builddir/build/BUILD/Python-3.12.5/Include/internal '
+                    '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
-                    '-I/builddir/build/BUILD/Python-3.12.5/Include -fPIC -fPIC',
+                    '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
- 'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.5/Modules/_hacl/include '
+ 'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                   '-fcf-protection -fexceptions -fcf-protection -fexceptions '
-                   '-fcf-protection -fexceptions   -O3 -flto=auto '
+                   '-fexceptions -fcf-protection -fexceptions -fcf-protection '
+                   '-fexceptions -fcf-protection   -O3 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Wno-complain-wrong-lang '
                    '-Werror=format-security '
@@ -741,9 +741,9 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                    '-fwrapv -O3 -fprofile-use -fprofile-correction '
-                   '-I/builddir/build/BUILD/Python-3.12.5/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.12.5/Include -fPIC -fPIC',
+                   '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -752,9 +752,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-                    '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                    '-fexceptions   -O3 -flto=auto -ffat-lto-objects '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                    '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                    '-fcf-protection   -O3 -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                     '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -782,9 +782,9 @@ build_time_vars = {'ABIFLAGS': '',
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
                     '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                     '-fwrapv -O3 -fprofile-use -fprofile-correction '
-                    '-I/builddir/build/BUILD/Python-3.12.5/Include/internal '
+                    '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
-                    '-I/builddir/build/BUILD/Python-3.12.5/Include -fPIC -fPIC',
+                    '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -815,7 +815,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.12.5/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.12.6/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'array  _asyncio  _bisect  _contextvars  _csv  _heapq  '
@@ -873,7 +873,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32 -DWITH_GZFILEOP',
  'MODULE_BINASCII_LDFLAGS': '-lz',
  'MODULE_BINASCII_STATE': 'yes',
- 'MODULE_CMATH_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/_math.h',
+ 'MODULE_CMATH_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
  'MODULE_CMATH_STATE': 'yes',
  'MODULE_DEPS_SHARED': 'Modules/config.c',
@@ -884,7 +884,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_FCNTL_STATE': 'yes',
  'MODULE_GRP_STATE': 'yes',
  'MODULE_ITERTOOLS_LDFLAGS': '',
- 'MODULE_MATH_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/_math.h',
+ 'MODULE_MATH_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_math.h',
  'MODULE_MATH_LDFLAGS': '-lm',
  'MODULE_MATH_STATE': 'yes',
  'MODULE_MMAP_STATE': 'yes',
@@ -909,8 +909,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_TERMIOS_STATE': 'yes',
  'MODULE_TIME_LDFLAGS': '',
  'MODULE_TIME_STATE': 'yes',
- 'MODULE_UNICODEDATA_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/unicodedata_db.h '
-                            '/builddir/build/BUILD/Python-3.12.5/Modules/unicodename_db.h',
+ 'MODULE_UNICODEDATA_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/unicodedata_db.h '
+                            '/builddir/build/BUILD/Python-3.12.6/Modules/unicodename_db.h',
  'MODULE_UNICODEDATA_STATE': 'yes',
  'MODULE_XXLIMITED_35_STATE': 'yes',
  'MODULE_XXLIMITED_STATE': 'yes',
@@ -922,56 +922,56 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__ASYNCIO_STATE': 'yes',
  'MODULE__BISECT_STATE': 'yes',
  'MODULE__BLAKE2_CFLAGS': '',
- 'MODULE__BLAKE2_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2-config.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2-impl.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2b-load-sse2.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2b-load-sse41.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2b-ref.c '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2b-round.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2b.c '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2s-load-sse2.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2s-load-sse41.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2s-load-xop.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2s-ref.c '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2s-round.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/impl/blake2s.c '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/_blake2/blake2module.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/hashlib.h',
+ 'MODULE__BLAKE2_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2-config.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2-impl.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b-load-sse2.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b-load-sse41.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b-ref.c '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b-round.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b.c '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-load-sse2.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-load-sse41.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-load-xop.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-ref.c '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-round.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s.c '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/blake2module.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h',
  'MODULE__BLAKE2_LDFLAGS': '-lssl -lcrypto',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
  'MODULE__BZ2_STATE': 'yes',
- 'MODULE__CODECS_CN_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/mappings_cn.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_CN_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_cn.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_CN_STATE': 'yes',
- 'MODULE__CODECS_HK_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/mappings_hk.h  '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_HK_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_hk.h  '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_HK_STATE': 'yes',
- 'MODULE__CODECS_ISO2022_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/mappings_jisx0213_pair.h '
-                                '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/alg_jisx0201.h '
-                                '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/emu_jisx0213_2000.h '
-                                '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/multibytecodec.h '
-                                '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_ISO2022_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                                '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/alg_jisx0201.h '
+                                '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/emu_jisx0213_2000.h '
+                                '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
+                                '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_ISO2022_STATE': 'yes',
- 'MODULE__CODECS_JP_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/mappings_jisx0213_pair.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/alg_jisx0201.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/emu_jisx0213_2000.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/mappings_jp.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_JP_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/alg_jisx0201.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/emu_jisx0213_2000.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_jp.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_JP_STATE': 'yes',
- 'MODULE__CODECS_KR_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/mappings_kr.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_KR_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_kr.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_KR_STATE': 'yes',
  'MODULE__CODECS_LDFLAGS': '',
- 'MODULE__CODECS_TW_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/mappings_tw.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_TW_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_tw.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_TW_STATE': 'yes',
  'MODULE__COLLECTIONS_LDFLAGS': '',
  'MODULE__CONTEXTVARS_STATE': 'yes',
@@ -980,7 +980,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CRYPT_STATE': 'yes',
  'MODULE__CSV_STATE': 'yes',
  'MODULE__CTYPES_CFLAGS': '-fno-strict-overflow',
- 'MODULE__CTYPES_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_ctypes/ctypes.h',
  'MODULE__CTYPES_LDFLAGS': '-L/usr/lib64/../lib64 -lffi -ldl',
  'MODULE__CTYPES_MALLOC_CLOSURE': '',
  'MODULE__CTYPES_STATE': 'yes',
@@ -998,23 +998,23 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DBM_LDFLAGS': '-lgdbm_compat',
  'MODULE__DBM_STATE': 'yes',
  'MODULE__DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
- 'MODULE__DECIMAL_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_decimal/docstrings.h',
  'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
- 'MODULE__ELEMENTTREE_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/pyexpat.c',
+ 'MODULE__ELEMENTTREE_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/pyexpat.c',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
  'MODULE__GDBM_CFLAGS': '',
  'MODULE__GDBM_LDFLAGS': '-lgdbm',
  'MODULE__GDBM_STATE': 'yes',
  'MODULE__HASHLIB_CFLAGS': '',
- 'MODULE__HASHLIB_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/hashlib.h',
+ 'MODULE__HASHLIB_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h',
  'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
  'MODULE__HASHLIB_STATE': 'yes',
  'MODULE__HEAPQ_STATE': 'yes',
- 'MODULE__IO_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.5/Modules/_io',
- 'MODULE__IO_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/_io/_iomodule.h',
+ 'MODULE__IO_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_io',
+ 'MODULE__IO_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_io/_iomodule.h',
  'MODULE__IO_LDFLAGS': '',
  'MODULE__IO_STATE': 'yes',
  'MODULE__JSON_STATE': 'yes',
@@ -1023,61 +1023,61 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/hashlib.h \\ '
+ 'MODULE__MD5_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h \\ '
                      'Modules/_hacl/Hacl_Hash_MD5.h '
                      'Modules/_hacl/Hacl_Hash_MD5.c',
  'MODULE__MD5_STATE': 'disabled',
- 'MODULE__MULTIBYTECODEC_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/cjkcodecs/multibytecodec.h',
+ 'MODULE__MULTIBYTECODEC_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
- 'MODULE__MULTIPROCESSING_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.5/Modules/_multiprocessing',
+ 'MODULE__MULTIPROCESSING_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_multiprocessing',
  'MODULE__MULTIPROCESSING_STATE': 'yes',
  'MODULE__OPCODE_STATE': 'yes',
  'MODULE__OPERATOR_LDFLAGS': '',
  'MODULE__PICKLE_STATE': 'yes',
- 'MODULE__POSIXSHMEM_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.5/Modules/_multiprocessing',
+ 'MODULE__POSIXSHMEM_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_multiprocessing',
  'MODULE__POSIXSHMEM_LDFLAGS': '',
  'MODULE__POSIXSHMEM_STATE': 'yes',
  'MODULE__POSIXSUBPROCESS_STATE': 'yes',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/hashlib.h '
+ 'MODULE__SHA1_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA1.h '
                       'Modules/_hacl/Hacl_Hash_SHA1.c',
  'MODULE__SHA1_STATE': 'disabled',
- 'MODULE__SHA2_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/hashlib.h '
+ 'MODULE__SHA2_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h '
                       '\\ Modules/_hacl/libHacl_Hash_SHA2.a',
  'MODULE__SHA2_STATE': 'disabled',
- 'MODULE__SHA3_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/hashlib.h '
+ 'MODULE__SHA3_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA3.h '
                       'Modules/_hacl/Hacl_Hash_SHA3.c',
  'MODULE__SHA3_STATE': 'disabled',
  'MODULE__SIGNAL_LDFLAGS': '',
- 'MODULE__SOCKET_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/socketmodule.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/addrinfo.h '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/getaddrinfo.c '
-                        '/builddir/build/BUILD/Python-3.12.5/Modules/getnameinfo.c',
+ 'MODULE__SOCKET_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/socketmodule.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/addrinfo.h '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/getaddrinfo.c '
+                        '/builddir/build/BUILD/Python-3.12.6/Modules/getnameinfo.c',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.5/Modules/_sqlite',
- 'MODULE__SQLITE3_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/_sqlite/connection.h '
-                         '/builddir/build/BUILD/Python-3.12.5/Modules/_sqlite/cursor.h '
-                         '/builddir/build/BUILD/Python-3.12.5/Modules/_sqlite/microprotocols.h '
-                         '/builddir/build/BUILD/Python-3.12.5/Modules/_sqlite/module.h '
-                         '/builddir/build/BUILD/Python-3.12.5/Modules/_sqlite/prepare_protocol.h '
-                         '/builddir/build/BUILD/Python-3.12.5/Modules/_sqlite/row.h '
-                         '/builddir/build/BUILD/Python-3.12.5/Modules/_sqlite/util.h',
+ 'MODULE__SQLITE3_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite',
+ 'MODULE__SQLITE3_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/connection.h '
+                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/cursor.h '
+                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/microprotocols.h '
+                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/module.h '
+                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/prepare_protocol.h '
+                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/row.h '
+                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/util.h',
  'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
  'MODULE__SSL_CFLAGS': '',
- 'MODULE__SSL_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/_ssl.h '
-                     '/builddir/build/BUILD/Python-3.12.5/Modules/_ssl/cert.c '
-                     '/builddir/build/BUILD/Python-3.12.5/Modules/_ssl/debughelpers.c '
-                     '/builddir/build/BUILD/Python-3.12.5/Modules/_ssl/misc.c '
-                     '/builddir/build/BUILD/Python-3.12.5/Modules/_ssl_data.h '
-                     '/builddir/build/BUILD/Python-3.12.5/Modules/_ssl_data_111.h '
-                     '/builddir/build/BUILD/Python-3.12.5/Modules/_ssl_data_300.h '
-                     '/builddir/build/BUILD/Python-3.12.5/Modules/socketmodule.h',
+ 'MODULE__SSL_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl.h '
+                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl/cert.c '
+                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl/debughelpers.c '
+                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl/misc.c '
+                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl_data.h '
+                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl_data_111.h '
+                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl_data_300.h '
+                     '/builddir/build/BUILD/Python-3.12.6/Modules/socketmodule.h',
  'MODULE__SSL_LDFLAGS': '-lssl -lcrypto',
  'MODULE__SSL_STATE': 'yes',
  'MODULE__STATISTICS_LDFLAGS': '-lm',
@@ -1086,9 +1086,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__STRUCT_STATE': 'yes',
  'MODULE__SYMTABLE_LDFLAGS': '',
  'MODULE__TESTBUFFER_STATE': 'yes',
- 'MODULE__TESTCAPI_DEPS': '/builddir/build/BUILD/Python-3.12.5/Modules/_testcapi/testcapi_long.h '
-                          '/builddir/build/BUILD/Python-3.12.5/Modules/_testcapi/parts.h '
-                          '/builddir/build/BUILD/Python-3.12.5/Modules/_testcapi/util.h',
+ 'MODULE__TESTCAPI_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_testcapi/testcapi_long.h '
+                          '/builddir/build/BUILD/Python-3.12.6/Modules/_testcapi/parts.h '
+                          '/builddir/build/BUILD/Python-3.12.6/Modules/_testcapi/util.h',
  'MODULE__TESTCAPI_STATE': 'yes',
  'MODULE__TESTCLINIC_STATE': 'yes',
  'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
@@ -1115,7 +1115,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection -fexceptions',
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions -fcf-protection',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1151,9 +1151,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                             '-fcf-protection -fexceptions -fcf-protection '
-                             '-fexceptions -fcf-protection -fexceptions   -O3 '
-                             '-flto=auto -ffat-lto-objects -fexceptions -g '
+                             '-fexceptions -fcf-protection -fexceptions '
+                             '-fcf-protection -fexceptions -fcf-protection   '
+                             '-O3 -flto=auto -ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
                              '-Wno-complain-wrong-lang -Werror=format-security '
                              '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -1186,14 +1186,14 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-clash-protection -fcf-protection '
                              '-mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                              '-fwrapv -O3 -fprofile-use -fprofile-correction '
-                             '-I/builddir/build/BUILD/Python-3.12.5/Include/internal '
+                             '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.12.5/Include '
+                             '-I/builddir/build/BUILD/Python-3.12.6/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-              '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-              '-fexceptions   -O3',
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+              '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+              '-fcf-protection   -O3',
  'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Wno-complain-wrong-lang -Werror=format-security '
@@ -1223,12 +1223,12 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
                      '-fPIC -fwrapv -O3 -fprofile-use -fprofile-correction '
-                     '-I/builddir/build/BUILD/Python-3.12.5/Include/internal',
+                     '-I/builddir/build/BUILD/Python-3.12.6/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-                   '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                   '-fexceptions   -O3 -flto=auto -ffat-lto-objects '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                   '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                   '-fcf-protection   -O3 -flto=auto -ffat-lto-objects '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                    '-Wno-complain-wrong-lang -Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -1256,9 +1256,9 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
                    '-fwrapv -O3 -fprofile-use -fprofile-correction '
-                   '-I/builddir/build/BUILD/Python-3.12.5/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.12.5/Include -fPIC '
+                   '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,pack-relative-relocs '
                     '-Wl,-z,now -specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
@@ -1273,7 +1273,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Wl,--build-id=sha1 '
                     '-specs=/usr/lib/rpm/redhat/redhat-package-notes  -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.12.5/Include',
+                '-I/builddir/build/BUILD/Python-3.12.6/Include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 1,
  'PY_LDFLAGS': '',
@@ -1301,10 +1301,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
                         '-fcf-protection -fexceptions -fcf-protection '
-                        '-fexceptions -fcf-protection -fexceptions   -O3 '
-                        '-flto=auto -ffat-lto-objects -fexceptions -g '
+                        '-fexceptions -fcf-protection   -O3 -flto=auto '
+                        '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Wno-complain-wrong-lang -Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -1333,9 +1333,9 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
                         '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
                         '-fPIC -fwrapv -O3 -fprofile-use -fprofile-correction '
-                        '-I/builddir/build/BUILD/Python-3.12.5/Include/internal '
+                        '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.12.5/Include -fPIC',
+                        '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC',
  'PY_SUPPORT_TIER': 1,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1347,7 +1347,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.5/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.6/build/optimized',
  'SCRIPTDIR': '/usr/lib64',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1457,7 +1457,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_testcapi   Modules/_xxtestfuzz   Modules/cjkcodecs   '
             'Modules/expat   Objects   Parser   Programs   Python   '
             'Python/frozen_modules   Python/deepfreeze',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.12.5/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.12.6/Tools/gdb/libpython.py',
  'STATIC_LIBPYTHON': 0,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -1468,12 +1468,12 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.5/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.6/build/optimized '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.5/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.6/build/optimized '
                './python -E '
-               '/builddir/build/BUILD/Python-3.12.5/Tools/scripts/run_tests.py',
+               '/builddir/build/BUILD/Python-3.12.6/Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -1483,10 +1483,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': '/builddir/build/BUILD/Python-3.12.5/Tools/build/update_file.py',
+ 'UPDATE_FILE': '/builddir/build/BUILD/Python-3.12.6/Tools/build/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.12',
- 'VPATH': '/builddir/build/BUILD/Python-3.12.5',
+ 'VPATH': '/builddir/build/BUILD/Python-3.12.6',
  'WASM_ASSETS_DIR': './usr',
  'WASM_STDLIB': './usr/lib/python3.12/os.py',
  'WHEEL_PKG_DIR': '/usr/share/python3-wheels',
@@ -1503,9 +1503,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.12.5/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.12.5',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.12.6/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.12.6',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.12.5'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.12.6'}
